@@ -197,7 +197,8 @@ def _hvdisp_plot_records_2d(records,
 
 def plot_record_polygons(record_points,
                          center_time=True,
-                         scaling=10**-3,):
+                         scaling=10**-3,
+                         ):
     """
     Plots record hv.Points as polygons for record matrix.
 
@@ -389,6 +390,7 @@ def _range_plot(f, full_time_range, t_reference, **kwargs):
                              t_reference + int(x_range[1] * 1e9)),
                  t_reference=t_reference,
                  **kwargs)
+
     return wrapped
 
 
